Class: Lintity::EntityReportController
- Inherits:
-
ApplicationController
- Object
- ActionController::Base
- ApplicationController
- Lintity::EntityReportController
- Defined in:
- app/controllers/lintity/entity_report_controller.rb
Instance Method Summary collapse
-
#index ⇒ Object
Child controllers inheriting from this controller should set @records to an array of hashes with the structure described in the view.
Instance Method Details
#index ⇒ Object
Child controllers inheriting from this controller should set @records to an array of hashes with the structure described in the view.
8 9 10 |
# File 'app/controllers/lintity/entity_report_controller.rb', line 8 def index @records ||= [] end |